@@ -8,7 +8,6 @@ from .. import configuration, pyc_checker
 from ..pyc_checker.pyc import PycHandler
 from ..py_package import PackageStruct, PackageDescription
 from PyInstaller.utils.cliutils.archive_viewer import get_archive, get_data, get_content, get_archive_content
-from ..utils.banner import print_banner
 
 
 class CommonDump():
@@ -101,7 +100,6 @@ class CommonDump():
 
     def main(self, target_file: str, output_directory: str, thread: int = 0, timeout: int = 10, target_file_type: str = None, session_timeout: int = 120, plugin: List = [], decompile_file: List = None, struct_headers: str = None, **args):
         self.statistics_status()
-        print_banner()
         if struct_headers:
             if isinstance(struct_headers, List):
                 struct_headers = ''.join(struct_headers)
